---
name: Bug report
about: Create bug report
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Minimal runnable code to reproduce the behavior**
```
from tensorboardX import SummaryWriter
...
```

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment**
What is the result of 
`pip list|grep -E "torch|proto|tensor"`
If the version is too old, please try to update first.


**Python environment**
Which version of python are you using? Did you use Andconda or Virtualenv?

**Additional context**
Add any other context about the problem here.
